==> Villefort-0.1.1.9.tar.gz: Villefort-0.1.1.9/README.md <==
# Villefort
Villefort is a time managment system written in Haskell.

## Version 1.1.6
Now has 
-- accurate due rankings
-- total on today page

## How to copy data between versions of Villefort.
Install the new version through cabal
Navigate to ~/.cabal
Navigate to share/
Navigate into your architecture folder.
mines x86_64-linux-ghc-7.10.3
You should now see the two versions of Villefort

Villefort-0.1.1.0/
|-- data/
|   |-- date
|   |-- day
|   |-- todo.db
|-- templates/
|-- js.js

Villefort-0.1.1.1/
|-- data/
|   |-- date
|   |-- day
|   |-- todo.db
|-- templates/
|-- js.js

Just copy the data/todo.db from the old version into data/todo.db of the new version.

## Configure your villefort
create a custom main method in ~.villefort/villefort.hs example

```haskell
module Main where

import Villefort


main :: IO ()
main = villefort def {
           -- description			Title	       Subject
  daily = [[ "Water Plants with 50ml of water","Water Plants","Garden"]] -- tasks to run daily
  weekly = defWeekly {
      friday = [return ["Freaky Friday","Friday","Admin"] -- tasks to run every friday
      },
  port = 3001
    }
```

Then run ```Villefort --recompile```
the next time you run villefort it will run with your configuration.

The default configuration is located here https://github.com/Chrisr850/Villefort/blob/master/src/Villefort/Config.hs

# Home screen
![alt text](https://raw.githubusercontent.com/Chrisr850/Villefort/master/data/screen.png)
# Add new todos
![alt text](https://raw.githubusercontent.com/Chrisr850/Villefort/master/data/screen01.png)
# Stats page 

![alt text](https://raw.githubusercontent.com/Chrisr850/Villefort/master/data/screen02.png)

# To install 
1. Install cabal (https://www.haskell.org/platform/)
2. In terminal or command prompt run `cabal install Villefort`.
3. and then `cabal run Villefort`.
4. You will be able to see the homescreen by typing localhost:3002 into your favorite browser.

==> Villefort-0.1.1.14.tar.gz: Villefort-0.1.1.14/README.md <==
# Villefort
Villefort is a time managment system written in Haskell.

## Version 1.1.14
Now you can compare new weekly tab.
Fixed weekly bug.

[default config](https://github.com/Chrisr850/Villefort/blob/master/src/Villefort/Config.hs)

# Home screen
![alt text](https://raw.githubusercontent.com/Chrisr850/Villefort/master/data/screen.png)
# Add new todos
![alt text](https://raw.githubusercontent.com/Chrisr850/Villefort/master/data/screen01.png)
# Stats page 

![alt text](https://raw.githubusercontent.com/Chrisr850/Villefort/master/data/screen02.png)

# To install 
1. Install cabal (https://www.haskell.org/platform/)
2. In terminal or command prompt run `cabal install Villefort`.
3. and then `cabal run Villefort`.
4. You will be able to see the homescreen by typing localhost:3002 into your favorite browser.

## Configure your villefort
create a custom main method in ~.villefort/villefort.hs example

```haskell
module Main where

import Villefort


main :: IO ()
main = villefort def {
           -- description			Title	       Subject
  daily = [[ "","check calendar","admin"]] -- tasks to run daily
  weekly = defWeekly {
      friday = [return ["Freaky Friday","Friday","Admin"] -- tasks to run every friday
      },
  port = 3001
    }
```

Then run ```Villefort --recompile```
the next time you run villefort it will run with your configuration.

The default configuration is located here https://github.com/Chrisr850/Villefort/blob/master/src/Villefort/Config.hs


## How to copy data between versions of Villefort.
Install the new version through cabal
Navigate to ~/.cabal
Navigate to share/
Navigate into your architecture folder mines x86_64-linux-ghc-7.10.3
You should now see different versions of Villefort

Villefort-0.1.1.0/

    |-- data/
    |   |-- date
    |   |-- day
    |   |-- todo.db
    |-- templates/
    |-- js.js

Villefort-0.1.1.1/

	|-- data/
	|   |-- date
	|   |-- day
	|   |-- todo.db
	|-- templates/
	|-- js.js

Just copy the data/todo.db from the old version into data/todo.db of the new version.
Then remember to rebuild Villefort if you have a custom build.
 
    Villefort --recompile
